@@ -60,7 +60,7 @@ def main():
          }
        }
     
-    Documentation: https://greb.cheetahai.co/get-started/introduction
+    Documentation: https://grebmcp.com/get-started/introduction
     """
     pass
 
