@@ -2,7 +2,7 @@
 Greb Python Client SDK
 This allows users to integrate Greb into their own applications and AI agents.
 
-The client runs grep/glob searches LOCALLY on user's machine, then sends
+The client runs grep searches LOCALLY on user's machine, then sends
 candidates to the API server for AI-powered reranking and billing.
 """
 
@@ -18,7 +18,6 @@ from pydantic import BaseModel
 
 # Import local search tools
 from .pipeline.grep import GrepTool
-from .pipeline.glob import GlobTool
 from .pipeline.read import ReadTool
 from .pipeline.base import PipelineConfig, CandidateMatch
 
@@ -117,11 +116,8 @@ class GrebClient:
         self.max_retries = max_retries
         
         # Initialize LOCAL search tools (run on user's machine)
-        max_grep = max_grep_results or int(os.getenv("MAX_GREP_RESULTS", "10000"))
-        max_glob = int(os.getenv("MAX_GLOB_RESULTS", "50"))
         read_max_size = int(os.getenv("READ_MAX_FILE_SIZE", "5048576"))
-        self.grep_tool = GrepTool(max_results=max_grep)
-        self.glob_tool = GlobTool(max_results=max_glob)
+        self.grep_tool = GrepTool()
         self.read_tool = ReadTool(max_file_size=read_max_size)
         
         # HTTP client for API requests
@@ -138,40 +134,53 @@ class GrebClient:
     def search(
         self,
         query: str,
+        keywords: Dict[str, Any],
         directory: Optional[str] = None,
         file_patterns: Optional[List[str]] = None,
         max_results: Optional[int] = None
     ) -> SearchResponse:
         """
         Search for code using natural language query.
-        
+
         This method:
-        1. Runs grep/glob searches LOCALLY on your machine
-        2. Collects candidate matches
-        3. Sends candidates to API for AI-powered reranking
-        4. Returns ranked results with billing tracked
-        
+        1. Uses keywords provided by the calling agent
+        2. Runs grep searches LOCALLY on your machine
+        3. Collects candidate matches
+        4. Sends candidates to API for AI-powered reranking
+        5. Returns ranked results with billing tracked
+
         Args:
             query: Natural language description of what you're looking for
+            keywords: Extracted keywords from agent with structure:
+                {
+                    "primary_terms": ["term1", "term2"],
+                    "file_patterns": ["*.py", "*.js"],
+                    "intent": "description of search intent"
+                }
             directory: Directory to search in (absolute or relative path)
             file_patterns: File patterns to filter (e.g., ["*.py", "*.js"])
             max_results: Maximum number of results to return
-            
+
         Returns:
             SearchResponse containing ranked results
-            
+
         Example:
             ```python
+            keywords = {
+                "primary_terms": ["authentication", "middleware"],
+                "file_patterns": ["*.py", "*.js"],
+                "intent": "find authentication middleware"
+            }
             results = client.search(
                 query="authentication middleware functions",
+                keywords=keywords,
                 directory="./backend/src",
-                file_patterns=["*.py", "*.js"],
                 max_results=10
             )
             ```
         """
         # Use orchestrator pipeline - all custom logic removed
-        from .pipeline.orchestrator import PipelineOrchestrator
+        from .pipeline.orchestrator import create_orchestrator
         from .pipeline.base import PipelineConfig
 
         search_dir = os.path.abspath(directory) if directory else os.getcwd()
@@ -179,16 +188,17 @@ class GrebClient:
         # Create orchestrator config - server handles all Cerebras calls
         orchestrator_config = PipelineConfig(
             cerebras_api_key="",  # Server handles Cerebras
-            max_grep_results=int(os.getenv("MAX_GREP_RESULTS", "10000")),
-            max_glob_results=int(os.getenv("MAX_GLOB_RESULTS", "10")),
+            max_search_results=int(os.getenv("MAX_SEARCH_RESULTS", "10")),
             top_k_results=int(os.getenv("TOP_K_RESULTS", "10"))
         )
 
-        orchestrator = PipelineOrchestrator(orchestrator_config)
+        orchestrator = create_orchestrator(orchestrator_config)
 
-        # Use main search method - orchestrator handles keyword extraction and reranking via server
+        # Use main search method - orchestrator handles grep/read/reranking
+        # Agent provides keywords directly (no keyword extraction needed)
         response = orchestrator.search(
             query=query,
+            keywords=keywords,
             directory=search_dir,
             file_patterns=file_patterns,
             max_results=max_results,
