@@ -5,13 +5,24 @@ Provides tools for code search, file reading, and usage statistics.
 
 import asyncio
 import json
+import logging
 import os
 import sys
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, TypedDict
 
 import httpx
 from mcp.server.fastmcp import FastMCP
 
+# Suppress httpx INFO logs
+logging.getLogger("httpx").setLevel(logging.WARNING)
+
+
+class ExtractedKeywords(TypedDict):
+    """Structure for keywords extracted by the AI agent."""
+    primary_terms: List[str]  # Main search terms from the query (specific identifiers, function names, etc.)
+    file_patterns: List[str]  # File patterns to search (e.g., ["*.py", "*.js"])
+    intent: str               # Description of search intent
+
 class SyncHttpClientWrapper:
     """Wrapper to provide synchronous HTTP client for orchestrator."""
 
@@ -62,20 +73,52 @@ async def make_greb_request(method: str, url: str, headers: Dict[str, str], para
 
 
 @mcp.tool()
-async def code_search(query: str, directory: str = ".", file_patterns: List[str] = None, max_results: int = 10) -> str:
+async def code_search(
+    query: str,
+    keywords: ExtractedKeywords,
+    directory: str = ".",
+    file_patterns: List[str] = None
+) -> str:
     """Search code using natural language queries powered by AI.
 
     Args:
         query: Natural language description of what to find
+        keywords: Keywords extracted by the AI agent. Must include:
+            - primary_terms: Main search keywords (e.g., ["authentication", "middleware"])
+            - file_patterns: File extensions to search (e.g., ["*.py", "*.js"])
+            - intent: Brief description of what you're looking for
         directory: FULL ABSOLUTE PATH to directory to search in (required for MCP, optional, default: current directory)
-        file_patterns: File patterns to filter (optional)
-        max_results: Maximum number of results (optional, default: 10)
+        file_patterns: File patterns to filter (optional, overrides keywords.file_patterns)
 
-    IMPORTANT FOR MCP: Always provide the full absolute path to the directory.
-    Examples:
-        - Windows: "D:\\greb_website\\backend" or "C:\\myproject\\src"
-        - Linux/Mac: "/home/user/myproject/backend" or "/Users/username/project/src"
-        - Do NOT use relative paths like "backend" or "src" - they will not work correctly.
+    Example:
+        keywords = {
+            "primary_terms": ["authentication", "middleware"],
+            "file_patterns": ["*.js", "*.ts"],
+            "intent": "find authentication middleware functions"
+        }
+
+    CRITICAL - DIRECTORY PATH REQUIREMENTS:
+    
+    You MUST provide the FULL ABSOLUTE PATH to the current workspace directory you are working in.
+    DO NOT use relative paths like ".", "backend", or "src" - these will search the wrong location.
+    
+    How to get the correct workspace path:
+    1. Check your current workspace root directory (where your project files are located)
+    2. Use the FULL ABSOLUTE PATH of that workspace root
+    3. If you need to search a subdirectory, append it to the workspace root path
+    
+    Examples of CORRECT paths:
+        - Windows workspace: "D:\\greb_website" or "D:\\greb_website\\backend"
+        - Linux/Mac workspace: "/home/user/myproject" or "/home/user/myproject/backend"
+        - Current workspace: Use the full path shown in your workspace context
+    
+    Examples of WRONG paths (DO NOT USE):
+        - "." (relative, will search wrong directory)
+        - "backend" (relative, will search wrong directory)
+        - "src" (relative, will search wrong directory)
+    
+    AFTER SEARCH: Once you get results, use the readFile tool to read all files
+    line numbers shown in the highlights. This gives you full context without additional searches.
     """
     # Get API key from environment
     api_key = os.getenv("GREB_API_KEY")
@@ -96,32 +139,34 @@ async def code_search(query: str, directory: str = ".", file_patterns: List[str]
     }
 
     # Use orchestrator pipeline - all custom logic removed
-    from .pipeline.orchestrator import PipelineOrchestrator
+    from .pipeline.orchestrator import create_orchestrator
     from .pipeline.base import PipelineConfig
 
-  
+
     # Create orchestrator config - server handles all Cerebras calls
+    # Always return top 10 results
     orchestrator_config = PipelineConfig(
         cerebras_api_key="",  # Server handles Cerebras
-        max_grep_results=int(os.getenv("MAX_GREP_RESULTS", "10000")),
-        max_glob_results=int(os.getenv("MAX_GLOB_RESULTS", "10")),
-        top_k_results=max_results or int(os.getenv("TOP_K_RESULTS", "10"))
+        max_search_results=int(os.getenv("MAX_SEARCH_RESULTS", "10")),
+        top_k_results=10  # Fixed at 10
     )
 
-    orchestrator = PipelineOrchestrator(orchestrator_config)
+    orchestrator = create_orchestrator(orchestrator_config)
 
     # Create synchronous HTTP client for orchestrator
     sync_client = SyncHttpClientWrapper(API_BASE, headers)
 
     try:
-        # Use main search method - orchestrator handles keyword extraction and reranking via server
+        # Use main search method - orchestrator handles grep/read/reranking
+        # Agent provides keywords directly (no keyword extraction needed)
         response = await asyncio.get_event_loop().run_in_executor(
             None,
             lambda: orchestrator.search(
                 query=query,
+                keywords=keywords,
                 directory=directory,
                 file_patterns=file_patterns,
-                max_results=max_results,
+                max_results=10,  # Fixed at 10
                 server_client=sync_client
             )
         )
