@@ -28,14 +28,16 @@ class FileSpan:
 
 @dataclass
 class CandidateMatch:
-    """Represents a candidate match from grep/glob operations."""
+    """Represents a candidate match from grep operations."""
     path: str
     line_number: int
     matched_text: str
     context_before: str = ""
     context_after: str = ""
+    priority_score: float = 0.0  # Optional priority score for intelligent ranking
+    pre_filter_score: float = 0.0  # Optional pre-filter score before reranking
 
-    def to_span(self, window_size: int = 10) -> FileSpan:
+    def to_span(self, window_size: int = 3) -> FileSpan:
         """Convert to a FileSpan with context window."""
         # This would be implemented in the read tool
         return FileSpan(
@@ -63,19 +65,12 @@ class RankedResult(BaseModel):
 
 class PipelineConfig(BaseModel):
     """Configuration for the Greb pipeline."""
-    # Tool execution limits
-    max_grep_results: int = 10000
-    max_glob_results: int = 10
-    context_window_size: int = 5
+    # No hard limits - BM25 + FlashRank handle filtering
+    max_search_results: int = 1000
+    context_window_size: int = 3
 
     # Read tool configuration
     read_max_file_size: int = 5048576  # 5MB
-    read_window_size: int = 10
-    read_max_spans: int = 500
-    read_max_lines_per_file: int = 100
-    read_context_lines: int = 10
-    read_binary_sample_size: int = 1024
-    read_generic_window_size: int = 10
 
     # Cerebras configuration
     cerebras_api_key: str
@@ -95,7 +90,7 @@ class ExtractedKeywords(BaseModel):
     """Model for extracted keywords from natural language query."""
     primary_terms: List[str]  # Main technical terms to search for
     file_patterns: List[str]  # File patterns to limit search
-    search_terms: List[str]   # All terms to use in grep search
+    search_terms: List[str] = []  # Deprecated - not used, kept for backward compatibility
     intent: str              # User's intent summary
 
 
@@ -103,7 +98,7 @@ class QueryRequest(BaseModel):
     """Represents a query request from the OpenAI-compatible API."""
     query: str
     max_results: Optional[int] = None
-    tools: Optional[List[str]] = None  # ["grep", "glob", "read"]
+    tools: Optional[List[str]] = None  # ["grep", "read"]
 
 
 class QueryResponse(BaseModel):
