@@ -17,29 +17,21 @@ from .base import CandidateMatch
 class GrepTool:
     """Implements fast text search using ripgrep."""
 
-    def __init__(self, max_results: Optional[int] = None, ignore_file: Optional[str] = None):
-        self.max_results = max_results or int(os.getenv('MAX_GREP_RESULTS', '10000'))
+    def __init__(self, ignore_file: Optional[str] = None):
         self.rg_command = self._find_rg_command()
         self.ignore_file = ignore_file or self._find_ignore_file()
 
     def _find_ignore_file(self) -> Optional[str]:
         """Find the ignore file to use for ripgrep."""
-        # FIRST: Check for bundled .rgignore in package directory
-        package_dir = Path(__file__).parent.parent  # Go up to op-grep root
-        bundled_rgignore = package_dir / '.rgignore'
-        if bundled_rgignore.exists():
-            return str(bundled_rgignore)
-        
-        # SECOND: Look for .rgignore in search directory and parent directories
+        # FIRST: Look for .rgignore in search directory and parent directories
         current_dir = Path.cwd()
-
         while current_dir != current_dir.parent:
             rgignore_path = current_dir / '.rgignore'
             if rgignore_path.exists():
                 return str(rgignore_path)
             current_dir = current_dir.parent
 
-        # THIRD: Also check for .gitignore as fallback
+        # SECOND: Check for .gitignore as fallback
         current_dir = Path.cwd()
         while current_dir != current_dir.parent:
             gitignore_path = current_dir / '.gitignore'
@@ -47,6 +39,12 @@ class GrepTool:
                 return str(gitignore_path)
             current_dir = current_dir.parent
 
+        # THIRD: Use bundled .rgignore (excludes binaries, images, etc.)
+        package_dir = Path(__file__).parent.parent
+        bundled_rgignore = package_dir / '.rgignore'
+        if bundled_rgignore.exists():
+            return str(bundled_rgignore)
+
         return None
 
     def _find_rg_command(self) -> str:
@@ -111,7 +109,7 @@ class GrepTool:
         directory: Optional[str] = None,
         file_patterns: Optional[List[str]] = None,
         case_sensitive: bool = False,
-        context_lines: int = 2
+        context_lines: int = 3
     ) -> List[CandidateMatch]:
         """
         Search for a query string in files using ripgrep.
@@ -134,10 +132,10 @@ class GrepTool:
         directory: Optional[str] = None,
         file_patterns: Optional[List[str]] = None,
         case_sensitive: bool = False,
-        context_lines: int = 2
+        context_lines: int = 3
     ) -> List[CandidateMatch]:
         """Search using ripgrep when available."""
-        cmd = [self.rg_command, "--json", "--no-heading", "--line-number"]
+        cmd = [self.rg_command, "--json", "--no-heading", "--line-number", "--fixed-strings"]
 
         # Add context lines
         if context_lines > 0:
@@ -158,8 +156,7 @@ class GrepTool:
             for pattern in file_patterns:
                 cmd.extend(["--glob", pattern])
 
-        # Add max results limit
-        cmd.extend(["--max-count", str(self.max_results)])
+        # No max-count limit - BM25 + FlashRank handle filtering
 
         # Add query
         cmd.append(query)
@@ -168,24 +165,38 @@ class GrepTool:
         if directory:
             cmd.append(directory)
 
+        # Use Popen to capture partial results on timeout
         try:
-            result = subprocess.run(
+            process = subprocess.Popen(
                 cmd,
-                capture_output=True,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
                 text=True,
                 encoding='utf-8',
-                errors='replace',
-                timeout=30
+                errors='replace'
             )
-
-            if result.returncode != 0 and result.returncode != 1:
-                # Return code 1 means no matches found, which is OK
-                raise RuntimeError(f"ripgrep failed: {result.stderr}")
-
-            return self._parse_rg_output(result.stdout)
-
-        except subprocess.TimeoutExpired:
-            raise RuntimeError("Search timed out after 30 seconds")
+            
+            try:
+                stdout, stderr = process.communicate(timeout=3)
+                
+                if process.returncode != 0 and process.returncode != 1:
+                    # Return code 1 means no matches found, which is OK
+                    raise RuntimeError(f"ripgrep failed: {stderr}")
+                
+                return self._parse_rg_output(stdout)
+                
+            except subprocess.TimeoutExpired:
+                # Timeout after 3 seconds - kill process and get partial results
+                process.kill()
+                stdout, stderr = process.communicate()
+                
+                # Parse whatever partial output we got
+                partial_results = self._parse_rg_output(stdout)
+                return partial_results
+                
+        except Exception as e:
+            # Any other error, return empty list
+            return []
 
     
     def _parse_rg_output(self, output: Optional[str]) -> List[CandidateMatch]:
