@@ -7,23 +7,20 @@ from typing import List, Optional, Dict, Any
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from .base import FileSpan, CandidateMatch, PipelineConfig, QueryResponse, RankedResult
 from .grep import GrepTool
-from .glob import GlobTool
 from .read import ReadTool
 from .rerank import RerankTool
-from .keyword_extractor import KeywordExtractor
 from .token_tracker import token_tracker
 class PipelineOrchestrator:
     """Orchestrates the complete Greb pipeline."""
     def __init__(self, config: PipelineConfig):
         self.config = config
-        self.grep_tool = GrepTool(max_results=config.max_grep_results)
-        self.glob_tool = GlobTool(max_results=config.max_glob_results)
+        self.grep_tool = GrepTool()
         self.read_tool = ReadTool(max_file_size=config.read_max_file_size)
         self.rerank_tool = RerankTool(config)
-        self.keyword_extractor = KeywordExtractor(config)
     def search(
         self,
         query: str,
+        keywords: Dict[str, Any],
         directory: Optional[str] = None,
         file_patterns: Optional[List[str]] = None,
         max_results: Optional[int] = None,
@@ -33,9 +30,11 @@ class PipelineOrchestrator:
         Execute the complete search pipeline.
         Args:
             query: Natural language search query
+            keywords: Extracted keywords from agent (primary_terms, search_terms, file_patterns)
             directory: Directory to search in (default: current)
             file_patterns: File patterns to constrain search
             max_results: Override default max results
+            server_client: HTTP client for calling rerank endpoint
         Returns:
             QueryResponse with ranked results
         """
@@ -56,41 +55,31 @@ class PipelineOrchestrator:
                 # Stop counting after threshold to save time
                 if file_count > 10000:
                     break
-        # Choose tools based on directory size
-            # Always use only fast tools - glob is too slow (113 seconds for 10k files)
+        # Use grep for searching
         tools = ["grep", "read"]
-        # 1. Extract keywords using Python server
-        if not server_client:
-            raise ValueError("server_client is required for keyword extraction")
 
-        keyword_response = server_client.post(
-            "/v1/extract-keywords",
-            json={"query": query}
-        )
-        keyword_response.raise_for_status()
-        keyword_data = keyword_response.json()
+        # 1. Use keywords provided by agent
+        if not server_client:
+            raise ValueError("server_client is required for reranking")
 
         from .base import ExtractedKeywords
         extracted_keywords = ExtractedKeywords(
-            primary_terms=keyword_data.get("primary_terms", []),
-            search_terms=keyword_data.get("search_terms", []),
-            file_patterns=keyword_data.get("file_patterns", []),
-            intent=keyword_data.get("intent", query)
+            primary_terms=keywords.get("primary_terms", []),
+            search_terms=keywords.get("search_terms", []),
+            file_patterns=keywords.get("file_patterns", []),
+            intent=keywords.get("intent", query)
         )
+
         # Use extracted file patterns if none provided
         if file_patterns is None:
             file_patterns = extracted_keywords.file_patterns
 
-        # Multi-turn parallel search (optimized for speed)
-        # Dynamic scaling based on system resources
-        import os
-        cpu_count = os.cpu_count() or 4
-        MAX_TURNS = int(os.getenv("MAX_TURNS", "2"))  # Single turn for max speed
-        # Scale parallel searches to match system capacity (8x CPU cores for I/O-bound grep)
-        optimal_parallel = min(cpu_count * 8, int(os.getenv('MAX_PARALLEL_SEARCHES', '128')))
-        MAX_PARALLEL_SEARCHES = optimal_parallel
+        # Multi-turn parallel search
+        # Fixed: 2 turns, 2 searches per turn
+        MAX_TURNS = 2
+        MAX_PARALLEL_SEARCHES = 2
         all_candidates: List[CandidateMatch] = []
-        for turn in range(1, MAX_TURNS):
+        for turn in range(1, MAX_TURNS + 1):  # Fixed: range(1, 3) = [1, 2] for MAX_TURNS=2
             turn_start = time.time()
             # Determine which search terms to use for this turn
             # Turn 1: Primary terms, Turn 2: Secondary terms
@@ -99,6 +88,7 @@ class PipelineOrchestrator:
             else:
                 # Turn 2: Secondary terms + remaining primary terms
                 search_terms = extracted_keywords.search_terms[:MAX_PARALLEL_SEARCHES]
+
             # Execute parallel searches within this turn
             turn_candidates = []
             with ThreadPoolExecutor(max_workers=MAX_PARALLEL_SEARCHES) as executor:
@@ -112,46 +102,31 @@ class PipelineOrchestrator:
                             directory=directory,
                             file_patterns=file_patterns,
                             case_sensitive=False,
-                            context_lines=2
+                            context_lines=3
                         )
                         futures.append(('grep', term, future))
-                # Execute glob search in parallel if enabled
-                if "glob" in tools and turn == 1:
-                    future = executor.submit(
-                        self.glob_tool.find_files,
-                        patterns=file_patterns or ["*"],
-                        directory=directory,
-                        recursive=True
-                    )
-                    futures.append(('glob', 'pattern_search', future))
+                
                 # Wait for all parallel searches to complete
                 for tool_name, search_term, future in futures:
                     try:
                         if tool_name == 'grep':
-                            results = future.result()
+                            results = future.result(timeout=3)
                             turn_candidates.extend(results)
-                        elif tool_name == 'glob':
-                            files = future.result()
-                            glob_candidates = self.glob_tool.create_candidates_from_files(files, directory)
-                            turn_candidates.extend(glob_candidates)
                     except Exception as e:
                         print(f"     [WARNING]  Search failed for '{search_term}': {e}")
+
             turn_time = (time.time() - turn_start) * 1000
             all_candidates.extend(turn_candidates)
-        # 5. Remove duplicates and limit candidates
-        dedup_start = time.time()
+        
+        # 5. Remove duplicates
         unique_candidates = self._deduplicate_candidates(all_candidates)
-        unique_candidates = unique_candidates[:self.config.max_grep_results]
-        dedup_time = (time.time() - dedup_start) * 1000
-        # 6. Read file contents - use environment variables directly from read tool
-        read_start = time.time()
+        
+        # 6. Read file contents
         spans = self.read_tool.read_spans_from_candidates(
-            unique_candidates,
-            max_spans=self.config.max_grep_results
+            unique_candidates
         )
-        read_time = (time.time() - read_start) * 1000
+        
         # 7. Re-rank using Python server (passing spans with context to /v1/rerank)
-        rerank_start = time.time()
 
         # Convert spans (with full context) to format expected by rerank API
         rerank_candidates = []
@@ -164,18 +139,24 @@ class PipelineOrchestrator:
                 "score": 0.0
             })
 
-        # Send candidates to Python server for reranking
+        # Send candidates to Python server for reranking with keywords
         rerank_response = server_client.post(
             "/v1/rerank",
             json={
                 "query": query,
                 "candidates": rerank_candidates,
+                "keywords": {
+                    "primary_terms": extracted_keywords.primary_terms,
+                    "search_terms": extracted_keywords.search_terms,
+                    "file_patterns": extracted_keywords.file_patterns,
+                    "intent": extracted_keywords.intent
+                },
                 "max_results": max_results
             }
         )
         rerank_response.raise_for_status()
         rerank_data = rerank_response.json()
-        rerank_time = (time.time() - rerank_start) * 1000
+        
         # Convert server response to RankedResult objects
         ranked_results = []
         for result in rerank_data.get('results', []):
@@ -189,6 +170,7 @@ class PipelineOrchestrator:
             ))
         # 8. Generate overall reasoning and create response
         execution_time = (time.time() - start_time) * 1000  # Convert to ms
+        
         # Use server reasoning response instead of direct Cerebras call
         overall_reasoning = None
         # Results are already enhanced from rerank tool, no need for additional processing
@@ -217,26 +199,11 @@ class PipelineOrchestrator:
                 directory=directory,
                 file_patterns=file_patterns,
                 case_sensitive=False,
-                context_lines=2
+                context_lines=3
             )
             candidates.extend(matches)
         return candidates
-    def _execute_glob_search_with_keywords(
-        self,
-        keywords,
-        directory: str,
-        file_patterns: Optional[List[str]]
-    ) -> List[CandidateMatch]:
-        """Execute glob search using extracted keywords."""
-        # Use keywords file patterns if none provided
-        if file_patterns is None:
-            file_patterns = keywords.file_patterns
-        files = self.glob_tool.find_files(
-            patterns=file_patterns,
-            directory=directory,
-            recursive=True
-        )
-        return self.glob_tool.create_candidates_from_files(files, directory)
+    
     def _deduplicate_candidates(self, candidates: List[CandidateMatch]) -> List[CandidateMatch]:
         """Remove duplicate candidates based on path and line number."""
         seen = set()
@@ -268,6 +235,7 @@ class PipelineOrchestrator:
         self,
         file_path: str,
         query: str,
+        keywords: Dict[str, Any],
         context_lines: int = 5
     ) -> List[FileSpan]:
         """
@@ -275,14 +243,35 @@ class PipelineOrchestrator:
         Args:
             file_path: Path to the file
             query: Natural language search query
+            keywords: Extracted keywords from agent (search_terms)
             context_lines: Number of context lines
         Returns:
             List of matching FileSpans
         """
-        # Extract keywords from natural language query
-        extracted_keywords = self.keyword_extractor.extract_keywords(query)
+        # Use keywords provided by agent
+        search_terms = keywords.get("search_terms", [])
         return self.read_tool.search_and_read(
             file_path=file_path,
-            search_terms=extracted_keywords.search_terms,
+            search_terms=search_terms,
             context_lines=context_lines
-        )
\ No newline at end of file
+        )
+
+
+def create_orchestrator(config: PipelineConfig) -> PipelineOrchestrator:
+    """
+    Factory function to create the orchestrator.
+
+    Always returns IntelligentOrchestrator (3-turn, AST-based intelligent search).
+    Classic mode has been removed - intelligent search is the only mode.
+
+    Args:
+        config: Pipeline configuration
+
+    Returns:
+        IntelligentOrchestrator instance
+
+    Raises:
+        ImportError: If intelligent mode components are not available
+    """
+    from .intelligent_orchestrator import IntelligentOrchestrator
+    return IntelligentOrchestrator(config)
\ No newline at end of file
