@@ -22,22 +22,15 @@ class ReadTool:
 
     def _find_ignore_file(self) -> Optional[str]:
         """Find the ignore file to use for read operations."""
-        # FIRST: Check for bundled .rgignore in package directory
-        package_dir = Path(__file__).parent.parent  # Go up to op-grep root
-        bundled_rgignore = package_dir / '.rgignore'
-        if bundled_rgignore.exists():
-            return str(bundled_rgignore)
-        
-        # SECOND: Look for .rgignore in search directory and parent directories
+        # FIRST: Look for .rgignore in search directory and parent directories
         current_dir = Path.cwd()
-
         while current_dir != current_dir.parent:
             rgignore_path = current_dir / '.rgignore'
             if rgignore_path.exists():
                 return str(rgignore_path)
             current_dir = current_dir.parent
 
-        # THIRD: Also check for .gitignore as fallback
+        # SECOND: Check for .gitignore as fallback
         current_dir = Path.cwd()
         while current_dir != current_dir.parent:
             gitignore_path = current_dir / '.gitignore'
@@ -45,6 +38,12 @@ class ReadTool:
                 return str(gitignore_path)
             current_dir = current_dir.parent
 
+        # THIRD: Use bundled .rgignore (excludes binaries, images, etc.)
+        package_dir = Path(__file__).parent.parent
+        bundled_rgignore = package_dir / '.rgignore'
+        if bundled_rgignore.exists():
+            return str(bundled_rgignore)
+
         return None
 
     def _load_ignore_patterns(self) -> List[str]:
@@ -146,52 +145,44 @@ class ReadTool:
     def read_spans_from_candidates(
         self,
         candidates: List[CandidateMatch],
-        window_size: Optional[int] = None,
-        max_spans: Optional[int] = None
+        window_size: Optional[int] = None
     ) -> List[FileSpan]:
         """
         Convert CandidateMatch objects to FileSpan objects with context.
 
         OPTIMIZED: Uses concurrent file reading for better performance.
+        No limit on spans - BM25 + FlashRank handle filtering.
 
         Args:
             candidates: List of CandidateMatch objects
             window_size: Number of context lines around each match
-            max_spans: Maximum number of spans to return
 
         Returns:
             List of FileSpan objects
         """
-        # Environment variable is primary source, passed parameter is override only if explicitly provided
         window_size = window_size if window_size is not None else int(os.getenv('CONTEXT_WINDOW_SIZE', '3'))
-        max_spans = max_spans if max_spans is not None else int(os.getenv('READ_MAX_SPANS', '500'))
 
-        # Filter and limit candidates first
+        # Deduplicate by (file, line_number) - keep multiple results from same file on different lines
         unique_candidates = []
-        seen_files = set()
+        seen = set()
 
         for candidate in candidates:
-            if len(unique_candidates) >= max_spans:
-                break
-
             file_path = candidate.path
-            # Skip duplicate files
-            if file_path in seen_files:
-                continue
             # Skip ignored files
             if self._should_ignore_file(file_path):
                 continue
 
+            # Only skip exact duplicates (same file + same line)
+            key = (file_path, candidate.line_number)
+            if key in seen:
+                continue
+
+            seen.add(key)
             unique_candidates.append(candidate)
-            seen_files.add(file_path)
 
         # Use concurrent file reading for better performance
         spans = []
-        # OPTIMIZED: Dynamic scaling based on CPU cores for I/O-bound tasks
-        cpu_count = os.cpu_count() or 4
-        # For I/O-bound file reading, use 4x CPU cores but respect configured limits
-        optimal_workers = min(cpu_count * 4, int(os.getenv('READ_MAX_WORKERS', '64')))
-        max_workers = min(len(unique_candidates), optimal_workers)
+        max_workers = min(len(unique_candidates), int(os.getenv('READ_MAX_WORKERS', '64')))
 
         if max_workers == 0:
             return spans
@@ -217,8 +208,8 @@ class ReadTool:
                     # Skip files that can't be read
                     continue
 
-        # Return spans in original order for consistency
-        return spans[:max_spans]
+        # Return all spans - no limit, BM25 + FlashRank handle filtering
+        return spans
 
     def _read_candidate_file(
         self,
@@ -239,44 +230,6 @@ class ReadTool:
         except (FileNotFoundError, ValueError, Exception):
             return None
 
-    def read_multiple_files(
-        self,
-        file_paths: List[str],
-        max_lines_per_file: Optional[int] = None,
-        encoding: str = "utf-8"
-    ) -> List[FileSpan]:
-        """
-        Read multiple files, taking the first N lines from each.
-
-        Args:
-            file_paths: List of file paths to read
-            max_lines_per_file: Maximum number of lines to read per file
-            encoding: Default encoding
-
-        Returns:
-            List of FileSpan objects
-        """
-        spans = []
-        max_lines_per_file = max_lines_per_file or int(os.getenv('READ_MAX_LINES_PER_FILE', '100'))
-
-        for file_path in file_paths:
-            # Skip ignored files silently
-            if self._should_ignore_file(file_path):
-                continue
-            try:
-                span = self.read_file(
-                    file_path=file_path,
-                    start_line=1,
-                    end_line=max_lines_per_file,
-                    encoding=encoding
-                )
-                spans.append(span)
-            except (FileNotFoundError, ValueError):
-                # Skip files that can't be read
-                continue
-
-        return spans
-
     def search_and_read(
         self,
         file_path: str,
@@ -303,7 +256,7 @@ class ReadTool:
             lines = f.readlines()
 
         matches = []
-        context_lines = context_lines or int(os.getenv('READ_CONTEXT_LINES', '10'))
+        context_lines = context_lines or 3
 
         for line_num, line in enumerate(lines, 1):
             line_text = line.strip()
@@ -328,47 +281,6 @@ class ReadTool:
 
         return matches
 
-    def get_file_metadata(self, file_path: str) -> Dict[str, Union[str, int, float]]:
-        """
-        Get metadata about a file.
-
-        Args:
-            file_path: Path to the file
-
-        Returns:
-            Dictionary with file metadata
-        """
-        if not os.path.exists(file_path):
-            raise FileNotFoundError(f"File not found: {file_path}")
-
-        stat = os.stat(file_path)
-        path_obj = Path(file_path)
-
-        return {
-            "path": file_path,
-            "size": stat.st_size,
-            "modified": stat.st_mtime,
-            "extension": path_obj.suffix,
-            "name": path_obj.name,
-            "is_binary": self._is_binary_file(file_path)
-        }
-
-    def _is_binary_file(self, file_path: str, sample_size: Optional[int] = None) -> bool:
-        """
-        Check if a file is binary by reading a sample.
-
-        Args:
-            file_path: Path to the file
-            sample_size: Number of bytes to sample
-
-        Returns:
-            True if the file appears to be binary
-        """
-        sample_size = sample_size or int(os.getenv('READ_BINARY_SAMPLE_SIZE', '1024'))
-        with open(file_path, 'rb') as f:
-            sample = f.read(sample_size)
-            return b'\0' in sample  # Null bytes indicate binary
-
     def extract_function_or_class(
         self,
         file_path: str,
@@ -677,7 +589,7 @@ class ReadTool:
         for i, line in enumerate(lines):
             if target_name in line:
                 # Return a span around the match
-                window = int(os.getenv('READ_GENERIC_WINDOW_SIZE', '10'))
+                window = 3
                 start_line = max(1, i + 1 - window)
                 end_line = min(len(lines), i + 1 + window)
                 return self.read_file("", start_line, end_line)
